@@ -1,4 +1,3 @@
-import argparse
 import importlib
 import json
 from nanoid import generate
@@ -11,7 +10,6 @@ from cloudam_stream.core.streams import RedisConsumer, RedisProducer
 from cloudam_stream.core.utils.actor_utils import FlowStateUtils
 import pickle
 import os
-import sys
 
 
 ''' 
@@ -23,15 +21,15 @@ class StreamApp(object):
 
     def __init__(self, actor: Actor):
         self.actor = actor
-        self.actor_id: str = ""
+        self.actor_id: str = None
         self.upstream_actors_states = {}
         self.current_actor_state: str = actor_constant.ACTOR_STATE_READY
-        self.current_actor_name: str = ""
+        self.current_actor_name: str = None
         self.redis_client: StrictRedis = None
-        self.flow_depth: int
-        self.actor_level: int
+        self.flow_depth: int = None
+        self.actor_level: int = None
         self.state_manager: FlowStateUtils = None
-        self.parallel_index: int
+        self.parallel_index: int = None
 
     def check_failed(self, upstream_actors):
         all_failed = True
@@ -77,7 +75,7 @@ class StreamApp(object):
                     if self.check_failed(upstream_actors):
                         self.state_manager.update_actor_state(self.current_actor_name, self.parallel_index,
                                                               actor_constant.ACTOR_STATE_FAILED)
-                        break
+                        raise Exception("all upstream job failed!")
                     if self.check_finished(upstream_actors):
                         self.state_manager.update_actor_state(self.current_actor_name, self.parallel_index,
                                                               actor_constant.ACTOR_STATE_SUCCESS)
@@ -117,22 +115,7 @@ class StreamApp(object):
     '''
     处理SourceActor
     '''
-    def process_source_actor(self):
-        self.actor.begin()
-        self.loop_input_port()
-        self.actor.end()
-
-
-    '''
-    处理SinkActor
-    '''
-    def process_sink_actor(self):
-        self.actor.begin()
-        self.loop_input_port()
-        self.actor.end()
-
-
-    def process_compute_actor(self):
+    def process_actor(self):
         self.actor.begin()
         self.loop_input_port()
         self.actor.end()
@@ -256,29 +239,11 @@ class StreamApp(object):
         return args
 
     def run(self):
-        # parser = argparse.ArgumentParser(description='manual to this script')
-        # parser.add_argument('--actor_desc', type=str, default=None)
-        # parser.add_argument('--flow_depth', type=int, default=None)
-        # parser.add_argument('--actor_level', type=int, default=None)
-        # parser.add_argument('--redis_host', type=str, default=None)
-        # parser.add_argument('--flow_manager_server', type=str, default=None)
-        # parser.add_argument('--parallel_index', type=int, default=None)
-        # flow_manager_server = os.getenv("flow_manager_server")
         self.actor_id = os.getenv("actor_id")
         self.flow_depth = int(os.getenv("flow_depth"))
         self.actor_level = int(os.getenv("actor_level"))
         self.parallel_index = int(os.getenv("parallel_index"))
 
-
-        # actor_args = parser.parse_args()
-        # actor_desc = 'eyJuYW1lIjogIlNpbmsiLCAidmVyc2lvbiI6ICIxLjAiLCAicnVudGltZSI6ICJweXRob24zIiwgImFjdG9yX2ZpbGUiOiAiTXlTaW5rQWN0b3IucHkiLCAiYWN0b3JfY2xhc3MiOiAiTXlTaW5rQWN0b3IiLCAiZXhlY19kZXBlbmRzIjogW10sICJpbnB1dF9wb3J0cyI6IFt7Im5hbWUiOiAiaW50YWtlIiwgImNsYXNzIjogIlRleHRJbnB1dFBvcnQiLCAiY29ubmVjdCI6IFt7ImFjdG9yIjogIlBhcmFsbGVsIiwgInBvcnQiOiAic3VjY2VzcyJ9XX1dLCAicGFyYW1ldGVycyI6IFt7Im5hbWUiOiAiY3B1X2NvdW50IiwgImNsYXNzIjogIkludGVnZXJQYXJhbWV0ZXIiLCAiZGVmYXVsdCI6IDEsICJ2YWx1ZSI6IDF9LCB7Im5hbWUiOiAicGFydGl0aW9uIiwgImNsYXNzIjogIlN0cmluZ1BhcmFtZXRlciIsICJkZWZhdWx0IjogImMtNC0xIiwgInZhbHVlOiI6ICJjLTQtMSJ9XX0_'
-        # flow_manager_server = 'http://192.168.110.20:7020'
-        # actor_desc = actor_args.actor_desc
-        # flow_manager_server = actor_args.flow_manager_server
-        # self.flow_depth = actor_args.flow_depth
-        # self.actor_level = actor_args.actor_level
-        # self.parallel_index = actor_args.parallel_index
-        # redis_host = actor_args.redis_host
         redis_host = os.getenv("redis_host")
         pool = ConnectionPool(max_connections=1, host=redis_host, port=6379, password='123456')
         self.redis_client = StrictRedis(connection_pool=pool)
@@ -289,16 +254,8 @@ class StreamApp(object):
         # base64解码参数
         actor_desc_arg = base64_utils.decode(actor_desc)
         actor_json = json.loads(actor_desc_arg)
-        # actor_file = actor_json.get('actor_file')
-        # actor_class_name = actor_json.get('actor_class')
         self.current_actor_name = actor_json.get('name')
 
-        # input_ports = actor_json.get('input_ports', [])
-        # output_ports = actor_json.get('output_ports', [])
-        # actor_module = importlib.import_module(config.CUSTOMIZE_ACTOR_PATH + actor_class_name)
-        # actor_class = getattr(actor_module, actor_class_name)
-        # actor = actor_class()
-
         # set actor 变量参数
         params = self.get_actor_params(actor_json)
         print("actor_json>>>>"+json.dumps(actor_json))
@@ -313,18 +270,7 @@ class StreamApp(object):
         self.actor.set_output_ports(output_ports)
         # 设置actor状态为已开始
         self.actor_ready()
-        # 处理SourceActor
-        if isinstance(self.actor, SourceActor):
-            print("process_source_actor>>>>>start")
-            self.process_source_actor()
-            print("process_source_actor>>>>>end")
-        elif isinstance(self.actor, SinkActor):
-            print("process_sink_actor>>>>>start")
-            self.process_sink_actor()
-            print("process_sink_actor>>>>>end")
-        # 处理其他Actor(Compute Actor)
-        else:
-            print("process_compute_actor>>>>>start")
-            self.loop_input_port()
-            print("process_compute_actor>>>>>end")
+        print("process_source_actor>>>>>start")
+        self.process_actor()
+        print("process_source_actor>>>>>end")
 
