@@ -21,11 +21,10 @@ class OutputPort(Generic[T], Port):
         self._emit(data)
 
     def _emit(self, payload: T):
-        message_object = Message(payload, "0", type(self).__name__)
+        message_object = Message(payload, "0", type(payload).__name__)
         # 转二进制
         msg = message_object.serialize()
-        stream_name = self.channel
-        self.producer.produce(stream_name, msg)
+        self.producer.produce(self.channel, msg)
 
 
 class TextOutputPort(OutputPort[str]):
